@@ -61,8 +61,9 @@ def curve(
         res = res.rename(columns=symbols)
 
     # Reindex dates to start of month.
-    res = res.resample('MS').mean()
-    return res
+    if res is not None and len(res) > 0:
+        res = res.resample('MS').mean()
+        return res
 
 
 def curve_formula(
@@ -76,12 +77,14 @@ def curve_formula(
     """
     if matches is None:
         matches = find_symbols_in_query(formula)
-    if curve_dates is None or len(curve_dates) == 1:
+    if curve_dates is None or (is_sequence(curve_dates) and len(curve_dates) == 1):
         if is_sequence(curve_dates):
             curve_dates = curve_dates[0]
         q = limqueryutils.build_curve_query(symbols=matches, curve_date=curve_dates, column=column, curve_formula_str=formula)
         res = query(q)
         res = res.resample('MS').mean()
+        if isinstance(curve_dates, date):
+            res = res[['1']].rename(columns={'1': curve_dates.strftime("%Y/%m/%d")})
     else:
         dfs, res = [], None
         if not is_sequence(curve_dates):
@@ -89,7 +92,7 @@ def curve_formula(
         for d in curve_dates:
             rx = curve_formula(formula, column=column, curve_dates=(d,), matches=matches)
             if rx is not None:
-                rx = rx[['1']].rename(columns={'1': d.strftime("%Y/%m/%d")})
+                rx = rx[[ d.strftime("%Y/%m/%d")]]
                 dfs.append(rx)
         if len(dfs) > 0:
             res = pd.concat(dfs, 1)
@@ -224,7 +227,7 @@ def get_symbol_contract_list(
 
 
 def find_symbols_in_query(q: str) -> tuple:
-    m = re.findall(r'\w[a-zA-Z0-9_]+', q)
+    m = re.findall(r'\w[a-zA-Z0-9_.]+', q)
     if 'Show' in m:
         m.remove('Show')
     rel = relations(tuple(m)).T
@@ -232,3 +235,10 @@ def find_symbols_in_query(q: str) -> tuple:
     if len(rel) > 0:
         return tuple(rel['name'])
     return ()
+
+
+if __name__ == '__main__':
+    q = 'Show 1: FP/7.45-FB'
+    find_symbols_in_query(q)
+    contracts('NYMEX.CU')
+    # series('PGABM00')
\ No newline at end of file
